@@ -13,10 +13,9 @@
 # the License.
 
 import time
+from unittest import mock
 import uuid
 
-import mock
-
 from pycadf import attachment
 from pycadf import cadftype
 from pycadf import credential
